@@ -147,7 +147,7 @@ def moveInHaving(inner, outer, debug=False):
     
     for outexpr in outer.joincond.children.filter(lambda x: x.getTables() <= (inner.getTables() + L(inner))
                                                and not x.isagg() # and x.getTables()[0] == inner 
-                                               and x.getRef(oldtables=L(inner)).isagg()
+                                               and x.getRef().isagg()
                                                ):
         
         havingexpr = outexpr.getRef(oldtables=L(inner))
@@ -470,9 +470,11 @@ def mergeGrouped(self, debug=False, subquery=False):
     for tablegroup in alltablegroups:
         
         merged = tablegroup.fold(lambda x, y: x @ y)
+        # if self not in tablegroup:
         self.setSource(merged, oldtable=tablegroup)
         
         if self in tablegroup:
+            
             moveInHaving(inner=merged, outer=self)
             
             # merge with a subquery and convert the agg exprs
